@@ -177,12 +177,9 @@ class GoogleAuth(ApiAttributeMixin):
     ):
         """Create an instance of GoogleAuth.
 
-        This constructor just sets the path of settings file.
-        It does not actually read the file.
-
         :param settings_file: path of settings file. 'settings.yaml' by default.
         :type settings_file: str.
-        :param settings: settigs dict.
+        :param settings: settings dict.
         :type settings: dict.
         """
         self.http_timeout = http_timeout
@@ -215,13 +212,17 @@ class GoogleAuth(ApiAttributeMixin):
 
     @CheckAuth
     def LocalWebserverAuth(
-        self, host_name="localhost", port_numbers=None, launch_browser=True
+        self,
+        host_name="localhost",
+        port_numbers=None,
+        launch_browser=True,
+        bind_addr=None,
     ):
         """Authenticate and authorize from user by creating local web server and
         retrieving authentication code.
 
-        This function is not for web server application. It creates local web server
-        for user from standalone application.
+        This function is not for web server application. It creates local web
+        server for user from standalone application.
 
         :param host_name: host name of the local web server.
         :type host_name: str.
@@ -229,6 +230,10 @@ class GoogleAuth(ApiAttributeMixin):
         :type port_numbers: list.
         :param launch_browser: should browser be launched automatically
         :type launch_browser: bool
+        :param bind_addr: optional IP address for the local web server to listen on.
+            If not specified, it will listen on the address specified in the
+            host_name parameter.
+        :type bind_addr: str.
         :returns: str -- code returned from local web server
         :raises: AuthenticationRejected, AuthenticationError
         """
@@ -244,7 +249,7 @@ class GoogleAuth(ApiAttributeMixin):
             port_number = port
             try:
                 httpd = ClientRedirectServer(
-                    (host_name, port), ClientRedirectHandler
+                    (bind_addr or host_name, port), ClientRedirectHandler
                 )
             except OSError:
                 pass
